@@ -1,7 +1,7 @@
 from typing import List, Optional, Dict
 
 from dataclasses import dataclass, field
-from code_loader.contract.enums import DatasetMetadataType, LeapDataType, Metric
+from code_loader.contract.enums import DatasetMetadataType, LeapDataType, MetricEnum
 
 
 @dataclass
@@ -56,7 +56,7 @@ class CustomLayerInstance:
 class PredictionTypeInstance:
     name: str
     labels: List[str]
-    metrics: Optional[List[Metric]] = None
+    metrics: Optional[List[MetricEnum]] = None
     custom_metrics: Optional[List[str]] = None
 
 
